@@ -1,4 +1,4 @@
-use ::std::fmt;
+use std::fmt;
 
 pub struct DisplayBandwidth {
     pub bandwidth: f64,
@@ -10,20 +10,17 @@ impl fmt::Display for DisplayBandwidth {
         let suffix = if self.as_rate { "ps" } else { "" };
         if self.bandwidth > 999_999_999_999.0 {
             // 1024 * 1024 * 1024 * 1024
-            write!(
-                f,
-                "{:.2}TiB{}",
-                self.bandwidth / 1_099_511_627_776.0,
-                suffix
-            )
+            write!(f, "{:.2}TiB{suffix}", self.bandwidth / 1_099_511_627_776.0,)
         } else if self.bandwidth > 999_999_999.0 {
-            write!(f, "{:.2}GiB{}", self.bandwidth / 1_073_741_824.0, suffix) // 1024 * 1024 * 1024
+            // 1024 * 1024 * 1024
+            write!(f, "{:.2}GiB{suffix}", self.bandwidth / 1_073_741_824.0)
         } else if self.bandwidth > 999_999.0 {
-            write!(f, "{:.2}MiB{}", self.bandwidth / 1_048_576.0, suffix) //  1024 * 1024
+            //  1024 * 1024
+            write!(f, "{:.2}MiB{suffix}", self.bandwidth / 1_048_576.0)
         } else if self.bandwidth > 999.0 {
-            write!(f, "{:.2}KiB{}", self.bandwidth / 1024.0, suffix)
+            write!(f, "{:.2}KiB{suffix}", self.bandwidth / 1024.0)
         } else {
-            write!(f, "{}B{}", self.bandwidth, suffix)
+            write!(f, "{}B{suffix}", self.bandwidth)
         }
     }
 }
