@@ -1,9 +1,11 @@
-use ::tui::backend::Backend;
-use ::tui::layout::{Alignment, Rect};
-use ::tui::style::{Modifier, Style};
-use ::tui::terminal::Frame;
-use ::tui::text::Span;
-use ::tui::widgets::Paragraph;
+use ratatui::{
+    backend::Backend,
+    layout::{Alignment, Rect},
+    style::{Modifier, Style},
+    terminal::Frame,
+    text::Span,
+    widgets::Paragraph,
+};
 
 pub struct HelpText {
     pub paused: bool,
