@@ -7,10 +7,10 @@
 // that implements the Backend TUI trait, but does nothing
 // this way, we don't need to create the TermionBackend
 // and thus skew our stdout when we don't need it
-use ::std::io;
-use ::tui::backend::Backend;
-use ::tui::buffer::Cell;
-use ::tui::layout::Rect;
+
+use std::io;
+
+use ratatui::{backend::Backend, buffer::Cell, layout::Rect};
 
 pub struct RawTerminalBackend {}
 
