@@ -1,8 +1,10 @@
-use ::std::cmp;
-use ::std::collections::{HashMap, HashSet, VecDeque};
-use ::std::hash::Hash;
-use ::std::iter::FromIterator;
-use ::std::net::{IpAddr, Ipv4Addr, Ipv6Addr};
+use std::{
+    cmp,
+    collections::{HashMap, HashSet, VecDeque},
+    hash::Hash,
+    iter::FromIterator,
+    net::{IpAddr, Ipv4Addr, Ipv6Addr},
+};
 
 use crate::network::{Connection, LocalSocket, Utilization};
 
@@ -79,10 +81,10 @@ pub struct UIState {
     pub total_bytes_downloaded: u128,
     pub total_bytes_uploaded: u128,
     pub cumulative_mode: bool,
-    utilization_data: VecDeque<UtilizationData>,
-    processes_map: HashMap<String, NetworkData>,
-    remote_addresses_map: HashMap<IpAddr, NetworkData>,
-    connections_map: HashMap<Connection, ConnectionData>,
+    pub utilization_data: VecDeque<UtilizationData>,
+    pub processes_map: HashMap<String, NetworkData>,
+    pub remote_addresses_map: HashMap<IpAddr, NetworkData>,
+    pub connections_map: HashMap<Connection, ConnectionData>,
 }
 
 impl UIState {
@@ -149,7 +151,7 @@ impl UIState {
                 total_bytes_uploaded += connection_info.total_bytes_uploaded;
 
                 let data_for_process = if let Some(process_name) =
-                    UIState::get_proc_name(&connections_to_procs, &connection.local_socket)
+                    UIState::get_proc_name(connections_to_procs, &connection.local_socket)
                 {
                     connection_data.process_name = process_name.clone();
                     processes.entry(process_name.clone()).or_default()
@@ -168,7 +170,7 @@ impl UIState {
             }
         }
         let divide_by = if self.utilization_data.is_empty() {
-            1 as u128
+            1_u128
         } else {
             self.utilization_data.len() as u128
         };
