@@ -6,80 +6,81 @@ mod os;
 #[cfg(test)]
 mod tests;
 
+use std::{
+    collections::HashMap,
+    net::Ipv4Addr,
+    process,
+    sync::{
+        atomic::{AtomicBool, AtomicUsize, Ordering},
+        Arc, Mutex, RwLock,
+    },
+    thread::{self, park_timeout},
+    time::{Duration, Instant},
+};
+
+use clap::{arg, Args, Parser};
+use crossterm::{
+    event::{Event, KeyCode, KeyEvent, KeyEventKind, KeyModifiers},
+    terminal,
+};
 use display::{elapsed_time, RawTerminalBackend, Ui};
 use network::{
     dns::{self, IpTable},
     LocalSocket, Sniffer, Utilization,
 };
-
-use ::crossterm::event::{Event, KeyCode, KeyEvent, KeyModifiers};
-use ::crossterm::terminal;
-use ::pnet::datalink::{DataLinkReceiver, NetworkInterface};
-use ::std::collections::HashMap;
-use ::std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
-use ::std::sync::{Arc, Mutex};
-use ::std::thread;
-use ::std::thread::park_timeout;
-use ::tui::backend::Backend;
-
-use std::process;
-
-use ::std::net::Ipv4Addr;
-use ::std::time::{Duration, Instant};
-use ::tui::backend::CrosstermBackend;
-use std::sync::RwLock;
-use structopt::StructOpt;
+use pnet::datalink::{DataLinkReceiver, NetworkInterface};
+use ratatui::backend::{Backend, CrosstermBackend};
 
 const DISPLAY_DELTA: Duration = Duration::from_millis(1000);
 
-#[derive(StructOpt, Debug)]
-#[structopt(name = "bandwhich")]
+#[derive(Parser, Debug)]
+#[command(name = "bandwhich")]
 pub struct Opt {
-    #[structopt(short, long)]
+    #[arg(short, long)]
     /// The network interface to listen on, eg. eth0
     interface: Option<String>,
-    #[structopt(short, long)]
+    #[arg(short, long)]
     /// Machine friendlier output
     raw: bool,
-    #[structopt(short, long)]
+    #[arg(short, long)]
     /// Do not attempt to resolve IPs to their hostnames
     no_resolve: bool,
-    #[structopt(flatten)]
+    #[command(flatten)]
     render_opts: RenderOpts,
-    #[structopt(short, long)]
+    #[arg(short, long)]
     /// Show DNS queries
     show_dns: bool,
-    #[structopt(short, long)]
+    #[arg(short, long)]
     /// A dns server ip to use instead of the system default
     dns_server: Option<Ipv4Addr>,
 }
 
-#[derive(StructOpt, Debug, Copy, Clone)]
+#[derive(Args, Debug, Copy, Clone)]
 pub struct RenderOpts {
-    #[structopt(short, long)]
+    #[arg(short, long)]
     /// Show processes table only
     processes: bool,
-    #[structopt(short, long)]
+    #[arg(short, long)]
     /// Show connections table only
     connections: bool,
-    #[structopt(short, long)]
+    #[arg(short, long)]
     /// Show remote addresses table only
     addresses: bool,
-    #[structopt(short, long)]
+    #[arg(short, long)]
     /// Show total (cumulative) usages
     total_utilization: bool,
 }
 
 fn main() {
     if let Err(err) = try_main() {
-        eprintln!("Error: {}", err);
+        eprintln!("Error: {err}");
         process::exit(2);
     }
 }
 
-fn try_main() -> Result<(), failure::Error> {
+fn try_main() -> anyhow::Result<()> {
     use os::get_input;
-    let opts = Opt::from_args();
+    let opts = Opt::parse();
     let os_input = get_input(&opts.interface, !opts.no_resolve, &opts.dns_server)?;
     let raw_mode = opts.raw;
     if raw_mode {
@@ -88,11 +89,13 @@ fn try_main() -> Result<(), failure::Error> {
     } else {
         match terminal::enable_raw_mode() {
             Ok(()) => {
-                let stdout = std::io::stdout();
+                let mut stdout = std::io::stdout();
+                // Ignore enteralternatescreen error
+                let _ = crossterm::execute!(&mut stdout, terminal::EnterAlternateScreen);
                 let terminal_backend = CrosstermBackend::new(stdout);
                 start(terminal_backend, os_input, opts);
             }
-            Err(_) => failure::bail!(
+            Err(_) => anyhow::bail!(
                 "Failed to get stdout: if you are trying to pipe 'bandwhich' you should use the --raw flag"
             ),
         }
@@ -226,10 +229,14 @@ where
                             Event::Key(KeyEvent {
                                 modifiers: KeyModifiers::CONTROL,
                                 code: KeyCode::Char('c'),
+                                kind: KeyEventKind::Press,
+                                ..
                             })
                             | Event::Key(KeyEvent {
                                 modifiers: KeyModifiers::NONE,
                                 code: KeyCode::Char('q'),
+                                kind: KeyEventKind::Press,
+                                ..
                             }) => {
                                 running.store(false, Ordering::Release);
                                 display_handler.unpark();
@@ -237,11 +244,19 @@ where
                                     Ok(_) => {}
                                     Err(_) => println!("Error could not disable raw input"),
                                 }
+                                let mut stdout = std::io::stdout();
+                                if crossterm::execute!(&mut stdout, terminal::LeaveAlternateScreen)
+                                    .is_err()
+                                {
+                                    println!("Error could not leave alternte screen");
+                                };
                                 break;
                             }
                             Event::Key(KeyEvent {
                                 modifiers: KeyModifiers::NONE,
                                 code: KeyCode::Char(' '),
+                                kind: KeyEventKind::Press,
+                                ..
                             }) => {
                                 let restarting = paused.fetch_xor(true, Ordering::SeqCst);
                                 if restarting {
@@ -260,6 +275,8 @@ where
                             Event::Key(KeyEvent {
                                 modifiers: KeyModifiers::NONE,
                                 code: KeyCode::Tab,
+                                kind: KeyEventKind::Press,
+                                ..
                             }) => {
                                 let paused = paused.load(Ordering::SeqCst);
                                 let elapsed_time = elapsed_time(
@@ -284,7 +301,7 @@ where
     let sniffer_threads = os_input
         .network_interfaces
         .into_iter()
-        .zip(os_input.network_frames.into_iter())
+        .zip(os_input.network_frames)
         .map(|(iface, frames)| {
             let name = format!("sniffing_handler_{}", iface.name);
             let running = running.clone();
