@@ -1,23 +1,11 @@
-use ::std::collections::HashMap;
+use std::collections::HashMap;
 
-use crate::network::LocalSocket;
-use crate::OpenSockets;
-
-use super::lsof_utils;
-
-#[derive(Debug)]
-struct RawConnection {
-    ip: String,
-    local_port: String,
-    remote_port: String,
-    protocol: String,
-    process_name: String,
-}
+use crate::{network::LocalSocket, os::lsof_utils::get_connections, OpenSockets};
 
 pub(crate) fn get_open_sockets() -> OpenSockets {
     let mut open_sockets = HashMap::new();
 
-    let connections = lsof_utils::get_connections();
+    let connections = get_connections();
 
     for raw_connection in connections {
         open_sockets.insert(
