@@ -1,14 +1,14 @@
 #[cfg(target_os = "linux")]
-pub(self) mod linux;
+mod linux;
 
 #[cfg(any(target_os = "macos", target_os = "freebsd"))]
-pub(self) mod lsof;
+mod lsof;
 
 #[cfg(any(target_os = "macos", target_os = "freebsd"))]
 mod lsof_utils;
 
 #[cfg(target_os = "windows")]
-pub(self) mod windows;
+mod windows;
 
 mod errors;
 pub(crate) mod shared;
