@@ -1,15 +1,14 @@
-use ::crossterm::event::read;
-use ::crossterm::event::Event;
-use ::pnet::datalink::Channel::Ethernet;
-use ::pnet::datalink::DataLinkReceiver;
-use ::pnet::datalink::{self, Config, NetworkInterface};
-use ::std::io::{self, ErrorKind, Write};
-use ::tokio::runtime::Runtime;
+use std::{
+    io::{self, ErrorKind, Write},
+    net::Ipv4Addr,
+    time,
+};
 
-use ::std::net::Ipv4Addr;
-use ::std::time;
+use crossterm::event::{read, Event};
+use pnet::datalink::{self, Channel::Ethernet, Config, DataLinkReceiver, NetworkInterface};
+use tokio::runtime::Runtime;
 
-use crate::os::errors::GetInterfaceErrorKind;
+use crate::{network::dns, os::errors::GetInterfaceError, OsInputOutput};
 
 #[cfg(target_os = "linux")]
 use crate::os::linux::get_open_sockets;
@@ -18,8 +17,6 @@ use crate::os::lsof::get_open_sockets;
 #[cfg(target_os = "windows")]
 use crate::os::windows::get_open_sockets;
 
-use crate::{network::dns, OsInputOutput};
-
 pub struct TerminalEvents;
 
 impl Iterator for TerminalEvents {
@@ -34,24 +31,26 @@ impl Iterator for TerminalEvents {
 
 pub(crate) fn get_datalink_channel(
     interface: &NetworkInterface,
-) -> Result<Box<dyn DataLinkReceiver>, GetInterfaceErrorKind> {
-    let mut config = Config::default();
-    config.read_timeout = Some(time::Duration::new(1, 0));
-    config.read_buffer_size = 65536;
+) -> Result<Box<dyn DataLinkReceiver>, GetInterfaceError> {
+    let config = Config {
+        read_timeout: Some(time::Duration::new(1, 0)),
+        read_buffer_size: 65536,
+        ..Default::default()
+    };
 
     match datalink::channel(interface, config) {
         Ok(Ethernet(_tx, rx)) => Ok(rx),
-        Ok(_) => Err(GetInterfaceErrorKind::OtherError(format!(
+        Ok(_) => Err(GetInterfaceError::OtherError(format!(
             "{}: Unsupported interface type",
             interface.name
         ))),
         Err(e) => match e.kind() {
-            ErrorKind::PermissionDenied => Err(GetInterfaceErrorKind::PermissionError(
+            ErrorKind::PermissionDenied => Err(GetInterfaceError::PermissionError(
                 interface.name.to_owned(),
             )),
-            _ => Err(GetInterfaceErrorKind::OtherError(format!(
-                "{}: {}",
-                &interface.name, e
+            _ => Err(GetInterfaceError::OtherError(format!(
+                "{}: {e}",
+                &interface.name
             ))),
         },
     }
@@ -83,7 +82,7 @@ where
     I: Iterator<
         Item = (
             &'a NetworkInterface,
-            Result<Box<dyn DataLinkReceiver>, GetInterfaceErrorKind>,
+            Result<Box<dyn DataLinkReceiver>, GetInterfaceError>,
         ),
     >,
 {
@@ -95,10 +94,10 @@ where
         |acc, (_, elem)| {
             if let Some(iface_error) = elem.err() {
                 match iface_error {
-                    GetInterfaceErrorKind::PermissionError(interface_name) => {
+                    GetInterfaceError::PermissionError(interface_name) => {
                         if let Some(prev_interface) = acc.permission {
                             return UserErrors {
-                                permission: Some(format!("{}, {}", prev_interface, interface_name)),
+                                permission: Some(format!("{prev_interface}, {interface_name}")),
                                 ..acc
                             };
                         } else {
@@ -111,12 +110,12 @@ where
                     error => {
                         if let Some(prev_errors) = acc.other {
                             return UserErrors {
-                                other: Some(format!("{} \n {}", prev_errors, error)),
+                                other: Some(format!("{prev_errors} \n {error}")),
                                 ..acc
                             };
                         } else {
                             return UserErrors {
-                                other: Some(format!("{}", error)),
+                                other: Some(format!("{error}")),
                                 ..acc
                             };
                         }
@@ -129,19 +128,17 @@ where
     if let Some(interface_name) = errors.permission {
         if let Some(other_errors) = errors.other {
             format!(
-                "\n\n{}: {} \nAdditional Errors: \n {}",
-                interface_name,
+                "\n\n{interface_name}: {} \nAdditional Errors: \n {other_errors}",
                 eperm_message(),
-                other_errors
             )
         } else {
-            format!("\n\n{}: {}", interface_name, eperm_message())
+            format!("\n\n{interface_name}: {}", eperm_message())
         }
     } else {
         let other_errors = errors
             .other
             .expect("asked to collect errors but found no errors");
-        format!("\n\n {}", other_errors)
+        format!("\n\n {other_errors}")
     }
 }
 
@@ -149,12 +146,12 @@ pub fn get_input(
     interface_name: &Option<String>,
     resolve: bool,
     dns_server: &Option<Ipv4Addr>,
-) -> Result<OsInputOutput, failure::Error> {
+) -> anyhow::Result<OsInputOutput> {
     let network_interfaces = if let Some(name) = interface_name {
-        match get_interface(&name) {
+        match get_interface(name) {
             Some(interface) => vec![interface],
             None => {
-                failure::bail!("Cannot find interface {}", name);
+                anyhow::bail!("Cannot find interface {name}");
                 // the homebrew formula relies on this wording, please be careful when changing
             }
         }
@@ -162,7 +159,7 @@ pub fn get_input(
         datalink::interfaces()
     };
 
-    #[cfg(any(target_os = "windows"))]
+    #[cfg(target_os = "windows")]
     let network_frames = network_interfaces
         .iter()
         .filter(|iface| !iface.ips.is_empty())
@@ -193,24 +190,22 @@ pub fn get_input(
     if available_network_frames.is_empty() {
         let all_errors = collect_errors(network_frames.clone());
         if !all_errors.is_empty() {
-            failure::bail!(all_errors);
+            anyhow::bail!(all_errors);
         }
 
-        failure::bail!("Failed to find any network interface to listen on.");
+        anyhow::bail!("Failed to find any network interface to listen on.");
     }
 
     let keyboard_events = Box::new(TerminalEvents);
     let write_to_stdout = create_write_to_stdout();
     let dns_client = if resolve {
-        let mut runtime = Runtime::new()?;
-        let resolver =
-            match runtime.block_on(dns::Resolver::new(runtime.handle().clone(), dns_server)) {
-                Ok(resolver) => resolver,
-                Err(err) => failure::bail!(
-                    "Could not initialize the DNS resolver. Are you offline?\n\nReason: {:?}",
-                    err
-                ),
-            };
+        let runtime = Runtime::new()?;
+        let resolver = match runtime.block_on(dns::Resolver::new(dns_server)) {
+            Ok(resolver) => resolver,
+            Err(err) => anyhow::bail!(
+                "Could not initialize the DNS resolver. Are you offline?\n\nReason: {err:?}"
+            ),
+        };
         let dns_client = dns::Client::new(resolver, runtime)?;
         Some(dns_client)
     } else {
@@ -248,7 +243,7 @@ fn eperm_message() -> &'static str {
 }
 
 #[inline]
-#[cfg(any(target_os = "windows"))]
+#[cfg(target_os = "windows")]
 fn eperm_message() -> &'static str {
     "Insufficient permissions to listen on network interface(s). Try running with administrator rights."
 }
