@@ -1,21 +1,24 @@
-use crate::tests::fakes::{create_fake_dns_client, NetworkFrames};
-
-use ::insta::assert_snapshot;
-use ::std::sync::{Arc, Mutex};
-
-use ::std::collections::HashMap;
-use ::std::net::IpAddr;
-
-use packet_builder::payload::PayloadData;
-use packet_builder::*;
-use pnet::datalink::DataLinkReceiver;
-use pnet::packet::Packet;
-
-use crate::tests::cases::test_utils::{
-    build_tcp_packet, opts_raw, os_input_output_dns, os_input_output_stdout, test_backend_factory,
+use std::{
+    collections::HashMap,
+    net::IpAddr,
+    sync::{Arc, Mutex},
 };
 
-use crate::{start, Opt, RenderOpts};
+use insta::assert_snapshot;
+use packet_builder::*;
+use pnet::{datalink::DataLinkReceiver, packet::Packet};
+
+use crate::{
+    start,
+    tests::{
+        cases::test_utils::{
+            build_tcp_packet, opts_raw, os_input_output_dns, os_input_output_stdout,
+            test_backend_factory,
+        },
+        fakes::{create_fake_dns_client, NetworkFrames},
+    },
+    Opt, RenderOpts,
+};
 
 fn build_ip_tcp_packet(
     source_ip: &str,
@@ -39,7 +42,7 @@ fn format_raw_output(output: Vec<u8>) -> String {
     use regex::Regex;
     let timestamp = Regex::new(r"<\d+>").unwrap();
     let replaced = timestamp.replace_all(&stdout_utf8, "<TIMESTAMP_REMOVED>");
-    format!("{}", replaced)
+    format!("{replaced}")
 }
 
 #[test]
